pub enum RecoverError {
InvalidMessageHash,
InvalidR,
InvalidS,
InvalidV,
}Expand description
Errors when performing ECDSA recover operations.
Variants
InvalidMessageHash
The message hash is not in the range of [0, 2^251).
InvalidR
The r value is not in the range of [0, 2^251).
InvalidS
The s value is not in the range of [0, 0x0800000000000010ffffffffffffffffb781126dcae7b2321e66a241adc64d2f).
InvalidV
The v value is neither 0 nor 1.