pub enum VerifyError {
InvalidPublicKey,
InvalidMessageHash,
InvalidR,
InvalidS,
}Expand description
Errors when performing ECDSA verify operations.
Variants
InvalidPublicKey
The public key is not a valid point on the STARK curve.
InvalidMessageHash
The message hash is not in the range of [0, 2^251).
InvalidR
The r value is not in the range of [0, 2^251).
InvalidS
The s value is not in the range of [0, 2^251).